@@ -110,9 +110,10 @@ class Plugin:
             return False
 
         for i in range(3, len(code) + 1):
-            if (
-                code[:i]
-                in self.options.select + list(self.options.extended_default_select) + self.options.enable_extensions
+            if code[:i] in (
+                self.options.select
+                + list(self.options.extended_default_select)
+                + (self.options.enable_extensions or [])
             ):
                 # Warn if opted-in
                 return True
